/*
 * Driver.h
 *
 *  Created on: 2009-02-15
 *      Author: stephane
 */

#ifndef DRIVER_H_
#define DRIVER_H_

/*************************************************************/
/*************************************************************/

/*
   //// Display interface \\\\
      // Control I/O port
      PORTx:0 --> CS2
      PORTx:1 --> CS1
      PORTx:2 --> RES!
      PORTx:3 --> R/W
      PORTx:4 --> D/I
      PORTx:5 --> E
      PORTx:6 --> NOT USED
      PORTx:7 --> BACK LIGHT

      // Data I/O port
      PORTx:0 --> LCD:DB0
      PORTx:1 --> LCD:DB1
      PORTx:2 --> LCD:DB2
      PORTx:3 --> LCD:DB3
      PORTx:4 --> LCD:DB4
      PORTx:5 --> LCD:DB5
      PORTx:6 --> LCD:DB6
      PORTx:7 --> LCD:DB7
*/

/*************************************************************/
/*************************************************************/
// If you want to use a different I/O port for LCD control & data,
// do it here!!!

// Define active I/O ports controlling the LCD

// Control I/O port
#define LCD_CONTROL_OUT PORTD
#define LCD_CONTROL_IN PIND
#define LCD_CONTROL_DDR DDRD

// Data I/O port
#define LCD_DATA_OUT PORTB
#define LCD_DATA_IN PINB
#define LCD_DATA_DDR DDRB

// Define LCD control signals
#define LCD_CS1 0
#define LCD_CS2 1
#define LCD_RES 2
#define LCD_RW 3
#define LCD_DI 4
#define LCD_E 5
//#define LCD_LED 7

/*************************************************************/
/*************************************************************/

#define LINE_1 0
#define LINE_2 1
#define LINE_3 2
#define LINE_4 3
#define LINE_5 4
#define LINE_6 5
#define LINE_7 6
#define LINE_8 7

// LCD busy status bit
#define LCD_BUSY 7

// Turn on power to the display, no cursor
#define   LCD_ON   0x3F
#define LCD_OFF    0x3E

#define PAGE_ADDRESS 0xB8
#define COLUMN_ADDRESS 0x40
#define Z_ADDRESS 0xC0

#define ACK 6

//#define LED_ON() LCD_CONTROL_OUT |= (1<<LCD_LED)
//#define LED_OFF() LCD_CONTROL_OUT &= ~(1<<LCD_LED)

void Init_Devices(void);
void LCD_Sleep(unsigned int time);
void LCD_Delay (unsigned int delay);
void LCD_PutData (unsigned char character, unsigned char chipselect);
void LCD_WrtCmd (unsigned char cmd, unsigned char chipselect);
void LCD_BusyWait (unsigned char chipselect);

void LCD_Init (void);
void LCD_ClearPage (unsigned char chipselect);
void LCD_ClearScreen (void);
char LCD_PutChar (unsigned char character);
unsigned char LCD_PutCursor (unsigned char x, unsigned char y);
void LCD_PutColumn (unsigned char character, unsigned char x, unsigned char y);
unsigned char LCD_GetColumn (unsigned char x, unsigned char y);
void LCD_PutString (const char *character, unsigned char x, unsigned char y);
void LCD_SetPixle (unsigned char x, unsigned char y);
void LCD_ClearPixle (unsigned char x, unsigned char y);
void LCD_DrawBox (unsigned char x1, unsigned char x2, unsigned char y1, unsigned char y2);
void LCD_DrawLine (unsigned char x1, unsigned char x2,  unsigned char y1, unsigned char y2);

unsigned char SwitchPressed(unsigned char Port, unsigned char Bit);


#endif /* DRIVER_H_ */
